
-- In a prefab file, you need to list all the assets it requires.
-- These can be either standard assets, or custom ones in your mod
-- folder.
local Assets =
{
	Asset("ANIM", "anim/basecamplantern.zip"), -- a standard asset
    Asset("ATLAS", "images/inventoryimages/basecamplantern.xml"),    -- a custom asset, found in the mod folder
}



local function turnon(inst)
    if not inst.components.fueled:IsEmpty() then
        if not inst.components.machine.ison then
            if inst.components.fueled then
                inst.components.fueled:StartConsuming()        
            end
            inst.Light:Enable(true)
            inst.AnimState:PlayAnimation("idle_on")

            inst.components.machine.ison = true

            inst.SoundEmitter:PlaySound("dontstarve/wilson/lantern_on")
            inst.SoundEmitter:PlaySound("dontstarve/wilson/lantern_LP", "loop")

--            inst.components.inventoryitem:ChangeImageName("brass_lantern")
        end
    end
end



local function turnoff(inst)
    if inst.components.fueled then
        inst.components.fueled:StopConsuming()        
    end

    inst.Light:Enable(false)
    inst.AnimState:PlayAnimation("idle_off")

    inst.components.machine.ison = false

    inst.SoundEmitter:KillSound("loop")
    inst.SoundEmitter:PlaySound("dontstarve/wilson/lantern_off")

--    inst.components.inventoryitem:ChangeImageName("brass_lantern")
end



local function ondropped(inst)
    turnoff(inst)
    turnon(inst)
end



local function onputininventory(inst)
    turnoff(inst)
end


local function nofuel(inst)
    local owner = inst.components.inventoryitem and inst.components.inventoryitem.owner
    if owner then
        owner:PushEvent("torchranout", {torch = inst})
    end

    turnoff(inst)
end


local function fuelupdate(inst)
    local fuelpercent = inst.components.fueled:GetPercent()
--    inst.Light:SetIntensity(Lerp(0.4, 0.6, fuelpercent))
    inst.Light:SetIntensity(Lerp(0.7, 0.8, fuelpercent))
--    inst.Light:SetRadius(Lerp(3, 5, fuelpercent))
    inst.Light:SetRadius(Lerp(6, 7, fuelpercent))
--    inst.Light:SetFalloff(.9)
    inst.Light:SetFalloff(.75)
end



local function takefuel(inst)
end


local function OnLoad(inst, data)
    if inst.components.machine and inst.components.machine.ison then
        inst.AnimState:PlayAnimation("idle_on")
        turnon(inst)
    else
        inst.AnimState:PlayAnimation("idle_off")
        turnoff(inst)
    end
end



-- Write a local function that creats, customizes, and returns an instance of the prefab.
local function fn(Sim)
	local inst = CreateEntity()
	inst.entity:AddTransform()
	inst.entity:AddAnimState()
    inst.entity:AddSoundEmitter()        

    MakeInventoryPhysics(inst)
    
    inst.AnimState:SetBank("basecamplantern")
    inst.AnimState:SetBuild("basecamplantern")
    inst.AnimState:PlayAnimation("idle")
    
    inst:AddTag("light")

    inst:AddComponent("inspectable")

    inst:AddComponent("inventoryitem")
	inst.components.inventoryitem.atlasname = "images/inventoryimages/basecamplantern.xml"
    inst.components.inventoryitem:SetOnDroppedFn(ondropped)
    inst.components.inventoryitem:SetOnPutInInventoryFn(onputininventory)    

    inst:AddComponent("fueled")
    inst.components.fueled.fueltype = "CAVE"
    inst.components.fueled.secondaryfueltype = "GASOLINE"

--    inst.components.fueled:InitializeFuelLevel(TUNING.LANTERN_LIGHTTIME*0.50)
    inst.components.fueled:InitializeFuelLevel(TUNING.LANTERN_LIGHTTIME*1.23*3.1)
    inst.components.fueled.rate = 1.23
    inst.components.fueled:SetDepletedFn(nofuel)
    inst.components.fueled:SetUpdateFn(fuelupdate)
    inst.components.fueled.ontakefuelfn = takefuel
    inst.components.fueled.accepting = true

    inst:AddComponent("machine")
    inst.components.machine.turnonfn = turnon
    inst.components.machine.turnofffn = turnoff
    inst.components.machine.cooldowntime = 0
    inst.components.machine.caninteractfn = function() return not inst.components.fueled:IsEmpty() end

    inst.entity:AddLight()
--    inst.Light:SetColour(240/255, 202/255, 100/255)
    inst.Light:SetColour(192/255, 183/255, 139/255)

    fuelupdate(inst)

    inst.OnLoad = OnLoad
    
    return inst
end

-- Add some strings for this item
STRINGS.NAMES.BASECAMPLANTERN = "Base Camp Lantern"
STRINGS.CHARACTERS.GENERIC.DESCRIBE.BASECAMPLANTERN = "It shines more blightly, more for a long time."


-- Finally, return a new prefab with the construction function and assets.
return Prefab( "common/inventory/basecamplantern", fn, Assets)

